Uses block-wise inversion of the negative Hessian, with a clear split between the regression coefficients (beta) and the Bernstein polynomial coefficients (gamma).
Usage
# S3 method for class 'spbp'
vcov(object, bp.param = FALSE, ...)Uses block-wise inversion of the negative Hessian, with a clear split between the regression coefficients (beta) and the Bernstein polynomial coefficients (gamma).
# S3 method for class 'spbp'
vcov(object, bp.param = FALSE, ...)