R/bp.basis.R
bp.basis.Rd
Bernstein basis polynomials calculations
bp.basis(time, degree, tau = max(time))
a vector of times.
Bernstein polynomial degree
must be greater than times maximum value observed.
A list containing matrices g and G corresponding BP basis and corresponding tau value used to compute them.