Proportional odds regression model specification
Source:R/parsnip-spsurv-data.R
proportional_odds.RdProportional odds survival regression with a Bernstein polynomial baseline
(bppo). This model type is registered by spsurv for use
with tidymodels; it is not part of the censored package.