Proportional odds survival regression with a Bernstein polynomial baseline
(bppo). This model type is registered by spsurv for use
with tidymodels; it is not part of the censored package.
proportional_odds(mode = "censored regression", engine = "spsurv")A model specification.
A single character string for the prediction outcome mode. The only possible value for this model is "censored regression".
A single character string specifying what computational engine to use for fitting.